@@ -7,6 +7,7 @@ import os
 import time, datetime
 import sys
 import shutil
+import cvdast
 from cvdastwrapper import runconfig
 from cvdastwrapper import apispecs
 
@@ -37,6 +38,11 @@ def init(inainfofname = "", specdir = ""):
             os.mkdir("tests/data")
         if not os.path.exists("savedattackinfo/attack_info.json"):
             print("Missing attack_info file, please run fuzzallspec.py to generate fuzzing test and test files. ")
+            file_path = os.path.join(os.path.dirname(os.path.abspath(cvdast.__file__)), 'templates/data/attack_info.json')
+            with open(file_path) as data_file:
+                data = json.load(data_file)
+                with open('tests/data/attack_info.json', 'w') as fd:
+                    json.dump(data, fd)
         else:
             shutil.copy("savedattackinfo/attack_info.json", "tests/data/")
 
