@@ -40,9 +40,15 @@ def moveToNoRetest(rval, api):
             del rval["skipped"]["retest"][api]
     if "no-retest" in rval["skipped"]:
         if api in rval["skipped"]["no-retest"] :
-            for x in rval["skipped"]["no-retest"][api]:
-                if x["reason"].find("Also") < 0 :
-                    x["reason"] += ". Also test calls with same attack type has generated passed/failed outcome."
+            if isinstance(rval["skipped"]["no-retest"][api], list):
+                for each_api in rval["skipped"]["no-retest"][api]:
+                    reason = each_api.get('reason')
+                if reason.find("Also") < 0 :
+                    rval["skipped"]["no-retest"][api][0]['reason'] += ". Also test calls with same attack type has generated passed/failed outcome."
+            else:
+                reason =rval["skipped"]["no-retest"][api].get('reason')
+                if reason.find("Also") < 0 :
+                    rval["skipped"]["no-retest"][api]['reason'] += ". Also test calls with same attack type has generated passed/failed outcome."
 # end moveToNoRetest
 
     
@@ -541,6 +547,20 @@ def genCSVPRows(spec, api, pri, t, apidef):
     return csvrows
 # end genCSVPRows
 
+#
+# A utility function to parse tests by attack category
+#
+def get_attack_by_category(failed_test):
+    result = ""
+    api_set = set()
+    for test_case in failed_test:
+        api = test_case.get('api', '')
+        if api in api_set:
+            continue
+        api_set.add(api)
+        result+=test_case.get('attack', '') + ',' + api + ',' + test_case.get('severity', '') + ',' + '\n'
+    return result
+# end get_attack_by_category
         
 #
 # pick specs, apis, and failed test severities,
@@ -548,7 +568,7 @@ def genCSVPRows(spec, api, pri, t, apidef):
 #  how to fix report for each of the vulnerabilities
 #
 #
-def sumFailedTestsToCSV(csvfname, failedr):
+def sumFailedTestsToCSV(csvfname, failedr, failed_tests):
 
     allrows=[[],[],[],[]]
     for ( spec, a ) in failedr.items():
@@ -570,13 +590,13 @@ def sumFailedTestsToCSV(csvfname, failedr):
                 continue
             
             if len(t[0]) > 0:
-                allrows[0].extend(genCSVPRows(spec, apiname, "P1", t[0],apidef))
+                allrows[0].extend(genCSVPRows(spec, apiname, "1", t[0],apidef))
             if len(t[1]) > 0:
-                allrows[1].extend(genCSVPRows(spec, apiname, "P2", t[1],apidef))
+                allrows[1].extend(genCSVPRows(spec, apiname, "2", t[1],apidef))
             if len(t[2]) > 0:
-                allrows[2].extend(genCSVPRows(spec, apiname, "P3", t[2],apidef))
+                allrows[2].extend(genCSVPRows(spec, apiname, "3", t[2],apidef))
             if len(t[3]) > 0:
-                allrows[3].extend(genCSVPRows(spec, apiname, "P4", t[3],apidef))
+                allrows[3].extend(genCSVPRows(spec, apiname, "4", t[3],apidef))
     csv ="API Fuzz Attack Security Testing Report, , , , ,\n"
     csv +=", , , , ,\n"
     csv +=",Test Method:, ,APIs are invoked with input parameter values set to invalid patterns from known attacks of various types. Service is considered potentially vulnerable if it responds with 200 Ok or worse with data., ,\n"
@@ -601,8 +621,17 @@ def sumFailedTestsToCSV(csvfname, failedr):
         csv += ", ,P"+str(n)+":,"+ str(c)+", ,\n"
         n+=1
     csv +=", , , , ,\n"
-    csv+="Specification Name, API Name, Priority, Test Info for Repro/Fix , Fuzz Attack Info,\n"
+    csv+="Specification Name, API Name, Severity, Test Info for Repro/Fix , Fuzz Attack Info,\n"
     csv+=tmpcsv
+
+    csv +=", , , , ,\n"
+    csv+=",Attack by categories:, , , ,\n"
+    csv +=", , , , ,\n"
+    res = get_attack_by_category(failed_tests)
+    if res:
+        csv+="Attack Categery, API, Severity,\n"
+        csv+=res
+
     f = open(csvfname, "w+")
     f.write(csv)
     f.close()
@@ -773,7 +802,8 @@ def sumperattack(csvfname, inspeclist=[], inattacklist=[]):
     rhtml += "<LI><font color=\"blue\"><b>P3</b></font>: When an API is called with parameter value set to patterns that were associated with known attacks that can cause critical/high severity damages, the API returns 200 OK with no data. Though it does not appear that the app is at risk of leaking data, the app might have processed the fuzzed input, which can cause subsequent security issues.\n"
     rhtml += "<LI><font color=\"black\"><b>P4</b></font>: When an API is called with parameter value set to patterns that were associated with known attacks that can cause medium/low severity damages, the API returns 200 OK with no data. Though it does not appear that the app is at risk of leaking data, the app might have processed the fuzzed input, which can cause subsequent security issues.\n"
     rhtml += "</UL>\n"
-    sumFailedTestsToCSV(csvfname, failedr)
+    failed_tests = tests.get('tested', {}).get('failed', [])
+    sumFailedTestsToCSV(csvfname, failedr, failed_tests)
     if runconfig.savefailedtestreport :
         if runconfig.usecustomreportfname:
              f = open(runconfig.customsavedreportfanme, "w+")
